/**
 * Pad a number with leading zeros.
 * @param num
 * @param size
 * @returns {string}
 */
function pad(num, size) {
    let s = num + "";
    while (s.length < size) s = "0" + s;
    return s;
}

/**
 * Format a date to the ONIX equivalent (YYYYMMDD)
 * @param d
 * @return {string}
 */
function formatDate(d) {
    d = new Date(d);
    return pad(d.getFullYear(), 4)+pad(d.getMonth()+1, 2)+pad(d.getDate(), 2);
}

/**
 * Parse a date from the ONIX format, to a Javascript date.
 * @param d
 * @return {Date}
 */
function parseDate(d) {
    if (d.length === 16) {
        return (new Date(d.slice(0, 4), Number(d.slice(4, 6)) - 1, d.slice(6, 8), d.slice(9, 11), d.slice(11, 13), d.slice(13, 15)));
    } else {
        let time = (new Date(d.slice(0, 4), Number(d.slice(4, 6)) - 1, d.slice(6, 8)));
        let offset = time.getTimezoneOffset();
        offset = Math.abs(offset / 60);
        time.setHours(time.getHours() + offset);
        return time;
    }
}

/**
 * Pluck the ONIX version from an XML string.
 * @param xml
 * @return {string|null}
 */
function getOnixVersionFromXML(xml) {
    if (!xml) return null;
    if (xml.includes("editeur.org/onix/3.0")) return "3.0";
    if (xml.includes("editeur.org/onix/2.1")) return "2.1";
    return null;
}

/**
 * Implementation of the partialRight function from lodash.
 * @param func
 * @param cachedArgs
 * @returns {function(...[*]): *}
 */
const partialRight = (func, ...cachedArgs) => (...args) => func(...args, ...cachedArgs);

module.exports = {
    pad: pad,
    formatDate: formatDate,
    parseDate: parseDate,
    getOnixVersionFromXML: getOnixVersionFromXML,
    partialRight: partialRight
};
