const XMLSchema = require("xml-schema");
const codes = require('./codes');
const schemas = require('./schemas');
const helpers = require('./helpers');

/**
 * Create an ONIX XML string from an object definition.
 * @param definition
 * @param onixVersion
 * @return {String|*}
 */
function create(definition, onixVersion = "3.0") {
    let onixSchema = getSchema(onixVersion);

    return onixSchema.generate(definition, {
        version: '1.0',
        encoding: 'UTF-8',
        standalone: false,
        pretty: true
    }, {
        sysID: onixSchema.sysID
    });
}

/**
 * Parse an ONIX XML string to an object definition.
 * @param xml
 * @param onixVersion
 * @return {*}
 */
function parse(xml, onixVersion = null) {
    if (!onixVersion) onixVersion = helpers.getOnixVersionFromXML(xml);
    let onixSchema = getSchema(onixVersion);
    return onixSchema.parse(xml.replace(/\<(\?xml|(\!DOCTYPE[^\>\[]+(\[[^\]]+)?))+[^>]+\>/g, ''));
}

/**
 * Locate the XML Schema for the given ONIX version.
 * @param onixVersion
 * @return {XMLSchema}
 */
function getSchema(onixVersion) {
    if (typeof onixVersion != 'undefined' && onixVersion === '3.0') {
        return new XMLSchema(schemas.Onix3);
    } else {
        return new XMLSchema(schemas.Onix21);
    }
}

module.exports = {
    parse: parse,
    create: create,
    codes: codes
};
