let helpers = require('../../helpers');
let OnixDate = require('./onixdate');

module.exports = {
    tag: 'Price',
    array: true,
    fields: {
        type: {
            tag: 'PriceType', // P.26.43
            transform: helpers.partialRight(helpers.pad, 2),
            untransform: Number,
            default: 1
        },
        qualifier: {
            tag: 'PriceQualifier',  // P.26.44
            transform: helpers.partialRight(helpers.pad, 2),
            untransform: Number,
            default: 5
        },
        status: {
            tag: 'PriceStatus',
            transform: helpers.partialRight(helpers.pad, 2),
            untransform: Number,
            default: 0
        },
        amount: {
            tag: 'PriceAmount',  // P.26.62
            transform: Number,
            untransform: function(s) { return Number(s.replace(',','.')); }
              // This is a hack to support the non-conformant data I have to handle where the decimal separator is comma instead of dot
        },
        currency: {
            tag: 'CurrencyCode',  // P.26.71
            transform: function(s) { return s.toUpperCase(); },
            default: 'USD'
        },
        territory: {
            tag: 'Territory',
            fields: {
                regionsIncluded: {
                    tag: 'RegionsIncluded'
                },
                countriesIncluded: {
                    tag: 'CountriesIncluded'
                },
                regionsExcluded: {
                    tag: 'RegionsExcluded'
                },
                countriesExcluded: {
                    tag: 'CountriesExcluded'
                }
            }
        },
        dates: {
            tag: 'PriceDate',
            fields: {
                role: {
                  tag: 'PriceDateRole', // P.26.83
                  default: 14,
                  transform: helpers.partialRight(helpers.pad, 2),
                  untransform: Number,
                },
                date: OnixDate
            },
            array: true
        }
    },
    map: {
        to: 'amount'
    }
};
