let helpers = require('../../helpers');
let Publisher = require('./publisher');
let Imprint = require('./imprint');
let OnixDate = require('./onixdate');
let SalesRights = require('./salesrights');
let CopyrightStatement = require('./copyrightstatement');

module.exports = {
    tag: 'PublishingDetail',
    fields: {
        'publisher': Publisher, // Group ~P.19
        'imprint': Imprint,
        'cityOfPublication': {
            tag: 'CityOfPublication',
            transform: String
        },
        'countryOfPublication': {
            tag: 'CountryOfPublication',
            transform: function(s) { return s.toUpperCase(); },
        },
        'status': { // P.20.1
            tag: 'PublishingStatus',
            transform: helpers.partialRight(helpers.pad, 2),
            untransform: Number,
            default: 4
        },
        'dates': {
            tag: 'PublishingDate',
            array: true,
            fields: {
                'role': {
                  tag: 'PublishingDateRole',
                  default: 1,
                  transform: helpers.partialRight(helpers.pad, 2),
                  untransform: Number,
                },
                'date': OnixDate
            }
        },
        'salesRights': SalesRights,
        'copyright': CopyrightStatement,
    }
};
