const chai = require("chai");
const onix = require('../src/index');
const expect = chai.expect;

let fs = require('fs');
let path = require('path');

describe('Create ONIX 3 XML from object', function () {
    it('should return empty XML', function() {
        let xml = onix.create();
        xml.should.be.instanceof(String);
    });

    it('should return XML from ONIX object', function() {
        // Arrange
        let expectedResult = fs.readFileSync(path.join(__dirname, './fixtures/expected-output.xml'), { encoding: "utf-8" });

        // Act
        let xml = onix.create({
          header: {
            sender: {
                name: "Joe Bloggs",
                emailAddress: "joe.bloggs@gmail.com"
            },
            addressee: {
                name: "RedCards"
            },
            sentDateTime: new Date(2022, 11, 21),
            defaultLanguageOfText: "eng",
            defaultCurrencyCode: "GBP"
          },
          products: [{
            record: "record",
            notification: 4,
            description: {
              title: {
                type: 9,
                element: {
                  level: 2,
                  text: 'Alice in Wonderland'
                }
              },
              languages: [{
                role: 1,
                code: 'eng'
              }]
            }
          }]
        });

        // Assert
        expect(xml.replace(/\s/g, "")).to.equal(expectedResult.replace(/\s/g, ""));
    });
});
