const helpers = require('../src/helpers');

describe('Helpers', function () {
    it('should correctly format a date', function () {
        let d = new Date(2022, 11, 23);
        helpers.formatDate(d).should.be.equal('20221223');
    });

    it('should correctly parse a date', function () {
        let d = helpers.parseDate('20170315').toString();
        d.valueOf().should.be.equal(new Date(2017, 2, 15).toString());
    });

    it('should correctly parse a date with time', function () {
        let d = helpers.parseDate('20170228T162554Z').toString();
        d.valueOf().should.be.equal(new Date(2017, 1, 28, 16, 25, 54).toString());
    });

    it('should correctly pad integer', function () {
        helpers.pad(5, 2).should.be.equal('05');
        helpers.pad(52, 4).should.be.equal('0052');
    });

    it('should correctly detect ONIX version from XML source', function () {
        let xml2 = '<?xml version="1.0" encoding="UTF-8"?><ONIXMessage xmlns="http://ns.editeur.org/onix/2.1/reference" release="2.1"></ONIXMessage>';
        let xml3 = '<?xml version="1.0" encoding="UTF-8"?><ONIXMessage xmlns="http://ns.editeur.org/onix/3.0/reference" release="3.0"></ONIXMessage>';

        helpers.getOnixVersionFromXML(xml2).should.be.equal('2.1');
        helpers.getOnixVersionFromXML(xml3).should.be.equal('3.0');
    });
});